@@ -1,11 +1,13 @@
 package Code::Includable::Tree::NodeMethods;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-02-24'; # DATE
+our $DATE = '2020-04-14'; # DATE
 our $DIST = 'Role-TinyCommons-Tree'; # DIST
-our $VERSION = '0.122'; # VERSION
+our $VERSION = '0.123'; # VERSION
 
 use strict;
+our $IGNORE_NO_CHILDREN_METHOD = 1;
+
 our $GET_PARENT_METHOD = 'parent';
 our $GET_CHILDREN_METHOD = 'children';
 our $SET_PARENT_METHOD = 'parent';
@@ -18,7 +20,16 @@ use Scalar::Util ();
 # like children, but always return list
 sub _children_as_list {
     my $self = shift;
-    my @children = $self->$GET_CHILDREN_METHOD;
+    my @children;
+    if ($IGNORE_NO_CHILDREN_METHOD) {
+        eval {
+            @children = $self->$GET_CHILDREN_METHOD;
+        };
+        return () if $@;
+    } else {
+        @children = $self->$GET_CHILDREN_METHOD;
+    }
+
     if (@children == 1) {
         return () unless defined($children[0]);
         return @{$children[0]} if ref($children[0]) eq 'ARRAY';
@@ -261,7 +272,7 @@ Code::Includable::Tree::NodeMethods - Tree node routines
 
 =head1 VERSION
 
-This document describes version 0.122 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2020-02-24.
+This document describes version 0.123 of Code::Includable::Tree::NodeMethods (from Perl distribution Role-TinyCommons-Tree), released on 2020-04-14.
 
 =head1 DESCRIPTION
 
@@ -278,6 +289,11 @@ object as the first argument, e.g.:
 
 =head1 VARIABLES
 
+=head2 $IGNORE_NO_CHILDREN_METHOD => bool (default: 1)
+
+If set to true (the default), when a node object does not support a "get
+children" method, we do not die and assume it does not have children.
+
 =head2 $GET_PARENT_METHOD => str (default: parent)
 
 The method names C<parent> can actually be customized by (locally) setting this
